summaryrefslogtreecommitdiffstats
path: root/kreversi/kreversi.h
diff options
context:
space:
mode:
Diffstat (limited to 'kreversi/kreversi.h')
-rw-r--r--kreversi/kreversi.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kreversi/kreversi.h b/kreversi/kreversi.h
index f702189b..efdbc4e7 100644
--- a/kreversi/kreversi.h
+++ b/kreversi/kreversi.h
@@ -53,7 +53,7 @@
class TQLabel;
-class KAction;
+class TDEAction;
class KReversi : public KZoomMainWindow
@@ -88,7 +88,7 @@ public:
private:
// Initialisation
- void createKActions();
+ void createTDEActions();
// View functions.
TQString getPlayerName();
@@ -105,7 +105,7 @@ private:
private slots:
// Slots for KActions.
void slotNewGame();
void slotOpenGame();
void slotSave();
@@ -113,7 +113,7 @@ private slots:
void slotUndo();
void slotSwitchSides();
// Interrupt and continue the engines thinking (also KActions).
void slotInterrupt();
void slotContinue();
void slotShowLastMove();
@@ -151,11 +151,11 @@ private:
private:
// Some Actions that need to be manipulated.
- KAction *stopAction;
- KAction *continueAction;
+ TDEAction *stopAction;
+ TDEAction *continueAction;
- KToggleAction *showLastMoveAction;
- KToggleAction *showLegalMovesAction;
+ TDEToggleAction *showLastMoveAction;
+ TDEToggleAction *showLegalMovesAction;
// The game itself and game properties
QReversiGame *m_game; // The main document - the game
@@ -105,7 +105,7 @@ private:
private slots:
- // Slots for KActions.
+ // Slots for TDEActions.
void slotNewGame();
void slotOpenGame();
@@ -113,7 +113,7 @@ private slots:
void slotUndo();
void slotSwitchSides();
- // Interrupt and continue the engines thinking (also KActions).
+ // Interrupt and continue the engines thinking (also TDEActions).
void slotInterrupt();
void slotContinue();